changeset 227:60b9c7a9938d

[project @ 2003-04-13 14:35:27 by bellard] comment fixes (Peter Lund)
author bellard
date Sun, 13 Apr 2003 14:35:27 +0000
parents db647b7feaa4
children f41bbafa11bf
files libtcc1.c tcc.c
diffstat 2 files changed, 19 insertions(+), 19 deletions(-) [+]
line wrap: on
line diff
--- a/libtcc1.c	Sun Apr 13 14:30:32 2003 +0000
+++ b/libtcc1.c	Sun Apr 13 14:35:27 2003 +0000
@@ -418,19 +418,19 @@
     return w;
 }
 
-/* XXX: suppress that and patch tcc to do it */
+/* XXX: fix tcc's code generator to do this instead */
 long long __sardi3(long long a, int b)
 {
     return a >> b;
 }
 
-/* XXX: suppress that and patch tcc to do it */
+/* XXX: fix tcc's code generator to do this instead */
 unsigned long long __shrdi3(unsigned long long a, int b)
 {
     return a >> b;
 }
 
-/* XXX: suppress that and patch tcc to do it */
+/* XXX: fix tcc's code generator to do this instead */
 long long __shldi3(long long a, int b)
 {
     return a << b;
@@ -439,11 +439,11 @@
 #if defined(__i386__)
 /* FPU control word for rounding to nearest mode */
 unsigned short __tcc_fpu_control = 0x137f;
-/* FPU control word for round to zero mode for int convertion */
+/* FPU control word for round to zero mode for int conversion */
 unsigned short __tcc_int_fpu_control = 0x137f | 0x0c00;
 #endif
 
-/* XXX: suppress that and patch tcc to do it */
+/* XXX: fix tcc's code generator to do this instead */
 float __ulltof(unsigned long long a)
 {
     DWunion uu; 
--- a/tcc.c	Sun Apr 13 14:30:32 2003 +0000
+++ b/tcc.c	Sun Apr 13 14:35:27 2003 +0000
@@ -266,7 +266,7 @@
 static int ch, tok;
 static CValue tokc;
 static CString tokcstr; /* current parsed string, if any */
-/* additionnal informations about token */
+/* additional informations about token */
 static int tok_flags;
 #define TOK_FLAG_BOL   0x0001 /* beginning of line before */
 #define TOK_FLAG_BOF   0x0002 /* beginning of file before */
@@ -346,7 +346,7 @@
 static int num_callers = 6;
 static const char **rt_bound_error_msg;
 
-/* XXX: suppress that ASAP */
+/* XXX: get rid of this ASAP */
 static struct TCCState *tcc_state;
 
 /* give the path of the tcc libraries */
@@ -813,7 +813,7 @@
 
 /* we use our own 'finite' function to avoid potential problems with
    non standard math libs */
-/* XXX: endianness dependant */
+/* XXX: endianness dependent */
 int ieee_finite(double d)
 {
     int *p = (int *)&d;
@@ -1200,7 +1200,7 @@
     if (s1->error_set_jmp_enabled) {
         longjmp(s1->error_jmp_buf, 1);
     } else {
-        /* XXX: suppress it someday */
+        /* XXX: eliminate this someday */
         exit(1);
     }
 }
@@ -2001,7 +2001,7 @@
     tokc = s->tokc;
 }
 
-/* return the number of additionnal 'ints' necessary to store the
+/* return the number of additional 'ints' necessary to store the
    token */
 static inline int tok_ext_size(int t)
 {
@@ -3810,7 +3810,7 @@
         tok_str_add2(&macro_str1, t, &cval);
     }
     saved_macro_ptr = macro_ptr;
-    /* XXX: suppress the use of macro_ptr here */
+    /* XXX: get rid of the use of macro_ptr here */
     macro_ptr = (int *)macro_str;
     for(;;) {
         while (*macro_ptr == TOK_TWOSHARPS) {
@@ -4206,7 +4206,7 @@
             }
             /* mark that stack entry as being saved on the stack */
             if (p->r & VT_LVAL) {
-                /* also suppress the bounded flag because the
+                /* also clear the bounded flag because the
                    relocation address of the function was stored in
                    p->c.ul */
                 p->r = (p->r & ~(VT_VALMASK | VT_BOUNDED)) | VT_LLOCAL;
@@ -4802,7 +4802,7 @@
 }
 
 /* handle integer constant optimizations and various machine
-   independant opt */
+   independent opt */
 void gen_opic(int op)
 {
     int fc, c1, c2, n;
@@ -5313,7 +5313,7 @@
                 gen_cvt_ftoi1(dbt);
             }
             if (dbt == VT_INT && (type->t & (VT_BTYPE | VT_UNSIGNED)) != dbt) {
-                /* additionnal cast for char/short/bool... */
+                /* additional cast for char/short/bool... */
                 vtop->type.t = dbt;
                 gen_cast(type);
             }
@@ -5326,7 +5326,7 @@
                     else
                         vtop->c.ll = vtop->c.i;
                 } else {
                     /* machine independant conversion */
                     gv(RC_INT);
                     /* generate high word */
                     if (sbt == (VT_INT | VT_UNSIGNED)) {
@@ -6929,7 +6929,7 @@
     }
 }
 
-/* XXX: suppress this mess */
+/* XXX: fix this mess */
 static void expr_land_const(void)
 {
     expr_or();
@@ -6940,7 +6940,7 @@
     }
 }
 
-/* XXX: suppress this mess */
+/* XXX: fix this mess */
 static void expr_lor_const(void)
 {
     expr_land_const();
@@ -7562,7 +7562,7 @@
                 expect("field");
             if (!notfirst)
                 *cur_field = f;
-            /* XXX: suppress this mess by using explicit storage field */
+            /* XXX: fix this mess by using explicit storage field */
             type1 = f->type;
             type1.t |= (type->t & ~VT_TYPE);
             type = &type1;
@@ -7586,7 +7586,7 @@
             f = *cur_field;
             if (!f)
                 error("too many field init");
-            /* XXX: suppress this mess by using explicit storage field */
+            /* XXX: fix this mess by using explicit storage field */
             type1 = f->type;
             type1.t |= (type->t & ~VT_TYPE);
             type = &type1;
@@ -5326,7 +5326,7 @@
                         vtop->c.ll = vtop->c.i;
                 } else {
-                    /* machine independant conversion */
+                    /* machine independent conversion */
                     gv(RC_INT);
                     /* generate high word */